@@ -1,6 +1,17 @@
 # -*- coding: utf-8 -*-
 """Python API Client for Axonius."""
-from . import api, auth, cli, constants, exceptions, http, logs, tools, version
+from . import (
+    api,
+    auth,
+    cli,
+    constants,
+    data_classes,
+    exceptions,
+    http,
+    logs,
+    tools,
+    version,
+)
 from .api import Adapters, Devices, Enforcements, System, Users
 from .auth import ApiKey
 from .connect import Connect
@@ -32,4 +43,5 @@ __all__ = (
     "constants",
     "cli",
     "logs",
+    "data_classes",
 )
