@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 """API models package."""
-from . import (adapters, assets, enforcements, entry, mixins, parsers, routers,
-               system)
+from . import adapters, assets, enforcements, entry, mixins, parsers, routers, system
 from .adapters import Adapters
 from .assets import Devices, Users
 from .enforcements import Enforcements, RunAction
