@@ -4,14 +4,26 @@ import time
 from typing import IO, List, Union
 
 from ...constants import CNX_GONE, CNX_RETRY, CNX_SANE_DEFAULTS, DEFAULT_NODE
-from ...exceptions import (CnxAddError, CnxGoneError, CnxTestError,
-                           CnxUpdateError, ConfigInvalidValue, ConfigRequired,
-                           NotFoundError)
+from ...exceptions import (
+    CnxAddError,
+    CnxGoneError,
+    CnxTestError,
+    CnxUpdateError,
+    ConfigInvalidValue,
+    ConfigRequired,
+    NotFoundError,
+)
 from ...tools import json_load, pathlib
 from ..mixins import ChildMixins
-from ..parsers.config import (config_build, config_default, config_empty,
-                              config_info, config_required, config_unchanged,
-                              config_unknown)
+from ..parsers.config import (
+    config_build,
+    config_default,
+    config_empty,
+    config_info,
+    config_required,
+    config_unchanged,
+    config_unknown,
+)
 from ..parsers.tables import tablize_cnxs, tablize_schemas
 
 
