@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
 """API models for working with adapters and connections."""
 import copy
-from typing import List
+from typing import List, Optional
 
-from ...constants import (AGG_ADAPTER_NAME, AGG_ADAPTER_TITLE, ALL_NAME,
-                          NORM_TYPE_MAP)
-from ...exceptions import ApiError
+from ...constants import (
+    AGG_ADAPTER_NAME,
+    AGG_ADAPTER_TITLE,
+    AGG_EXPR_FIELD_TYPE,
+    ALL_NAME,
+)
+from ...data_classes.fields import OperatorTypeMaps
 from ...tools import strip_left, strip_right
 
 
@@ -15,17 +19,20 @@ def parse_fields(raw: dict) -> dict:
     Returns:
         :obj:`dict`: parsed generic and adapter specific fields
     """
-    parsed = {}
-    parsed[AGG_ADAPTER_NAME] = parse_schemas(
+    agg_fields: List[dict] = parse_schemas(
         adapter_name=AGG_ADAPTER_NAME,
         adapter_title=AGG_ADAPTER_TITLE,
         adapter_name_raw=f"{AGG_ADAPTER_NAME}_adapter",
         adapter_prefix="specific_data.data",
         all_field="specific_data",
         raw_fields=raw["generic"],
-        details=True,
     )
 
+    agg_base_names: List[str] = [x["name_base"] for x in agg_fields]
+
+    parsed = {}
+    parsed[AGG_ADAPTER_NAME] = agg_fields
+
     for raw_name, raw_fields in raw["specific"].items():
         # raw_name = aws_adapter
 
@@ -44,7 +51,9 @@ def parse_fields(raw: dict) -> dict:
             adapter_title=title,
             all_field=prefix,
             raw_fields=raw_fields,
+            agg_base_names=agg_base_names,
         )
+
         parsed[name] = fields
 
     return parsed
@@ -73,9 +82,16 @@ def parse_complex(field: dict):
         col_name = field["column_name"]
         name_base = field["name_base"]
         prefix = field["adapter_prefix"]
-        field["sub_fields"] = sub_fields = []
-        items = field.pop("items")["items"]
+        items = field["items"].pop("items")
+        adapter_name = field["adapter_name"]
+        adapter_name_raw = field["adapter_name_raw"]
+        adapter_prefix = field["adapter_prefix"]
+        adapter_title = field["adapter_title"]
+        parent = field["name_qual"]
+        expr_field_type = field["expr_field_type"]
+        is_agg = field["is_agg"]
 
+        field["sub_fields"] = sub_fields = []
         field_names = [f["name"] for f in items]
 
         for sub_field in items:
@@ -88,14 +104,19 @@ def parse_complex(field: dict):
             sub_field["name_qual"] = sub_name_qual
             sub_field["is_root"] = is_root(name=sub_name, names=field_names)
             sub_field["is_list"] = sub_field["type"] == "array"
-            sub_field["parent"] = field["name_qual"]
-            sub_field["adapter_name"] = field["adapter_name"]
-            sub_field["adapter_name_raw"] = field["adapter_name_raw"]
-            sub_field["adapter_prefix"] = field["adapter_prefix"]
-            sub_field["adapter_title"] = field["adapter_title"]
+            sub_field["parent"] = parent
+            sub_field["adapter_name"] = adapter_name
+            sub_field["adapter_name_raw"] = adapter_name_raw
+            sub_field["adapter_prefix"] = adapter_prefix
+            sub_field["adapter_title"] = adapter_title
             sub_field["column_title"] = f"{col_title}: {sub_title}"
             sub_field["column_name"] = f"{col_name}.{sub_name}"
-            sub_field["type_norm"] = get_type_norm(field=sub_field)
+            sub_field["is_agg"] = is_agg
+            sub_field["expr_field_type"] = expr_field_type
+
+            type_map = OperatorTypeMaps.get_type_map(field=sub_field)
+            sub_field["type_norm"] = type_map.name
+            sub_field["selectable"] = True
             parse_complex(field=sub_field)
             sub_fields.append(sub_field)
 
@@ -107,9 +128,10 @@ def parse_schemas(
     adapter_title: str,
     all_field: str,
     raw_fields: List[dict],
-    details: bool = False,
+    agg_base_names: Optional[List[str]] = None,
 ) -> List[dict]:
     """Parse field schemas for an adapter."""
+    agg_base_names = agg_base_names or []
     fields = []
 
     fields.append(
@@ -130,12 +152,14 @@ def parse_schemas(
             "name_qual": all_field,
             "title": "All Adapter Specific Data",
             "type": "array",
-            "type_norm": "complex_complex",
+            "type_norm": "array_object_object",
             "selectable": True,
+            "is_agg": adapter_name == AGG_ADAPTER_NAME,
+            "expr_field_type": AGG_EXPR_FIELD_TYPE,
         }
     )
 
-    if details:
+    if adapter_name == AGG_ADAPTER_NAME:
         fields += [
             {
                 "adapter_name_raw": adapter_name_raw,
@@ -154,8 +178,10 @@ def parse_schemas(
                 "name_qual": "unique_adapter_names_details",
                 "title": "Unique Adapter Names Details Index",
                 "type": "array",
-                "type_norm": "list_string",
+                "type_norm": "array_string",
                 "selectable": False,
+                "is_agg": True,
+                "expr_field_type": AGG_EXPR_FIELD_TYPE,
             },
             {
                 "adapter_name_raw": adapter_name_raw,
@@ -174,8 +200,10 @@ def parse_schemas(
                 "name_qual": "meta_data.client_used",
                 "title": "Adapter Connection Details Index",
                 "type": "array",
-                "type_norm": "list_string",
+                "type_norm": "array_string",
                 "selectable": False,
+                "is_agg": True,
+                "expr_field_type": AGG_EXPR_FIELD_TYPE,
             },
         ]
 
@@ -197,12 +225,22 @@ def parse_schemas(
         field["parent"] = "root"
         field["column_title"] = f"{adapter_title}: {title}"
         field["column_name"] = f"{adapter_name}:{name_base}"
-        field["type_norm"] = get_type_norm(field=field)
+        type_map = OperatorTypeMaps.get_type_map(field=field)
+        field["type_norm"] = type_map.name
         field["selectable"] = True
+        field["is_agg"] = bool(agg_base_names) and name_base in agg_base_names
+
+        if adapter_name == AGG_ADAPTER_NAME:
+            field["expr_field_type"] = AGG_EXPR_FIELD_TYPE
+        else:
+            field["expr_field_type"] = adapter_name_raw
+
         parse_complex(field=field)
         fields.append(field)
-        if details:
+
+        if adapter_name == AGG_ADAPTER_NAME:
             field_details = copy.deepcopy(field)
+            field_details["name"] += "_details"
             field_details["name_base"] += "_details"
             field_details["name_qual"] += "_details"
             field_details["column_title"] += " Details"
@@ -213,18 +251,18 @@ def parse_schemas(
     return fields
 
 
-def get_type_norm(field: dict) -> str:
-    """Get the normalized type of a field."""
-    ftype = field["type"]
-    ffmt = field.get("format", "")
-    fitype = field.get("items", {}).get("type", "")
-    fifmt = field.get("items", {}).get("format", "")
-    check = (ftype, ffmt, fitype, fifmt)
+# def get_type_norm(field: dict) -> str:
+#     """Get the normalized type of a field."""
+#     ftype = field["type"]
+#     ffmt = field.get("format", "")
+#     fitype = field.get("items", {}).get("type", "")
+#     fifmt = field.get("items", {}).get("format", "")
+#     check = (ftype, ffmt, fitype, fifmt)
 
-    for norm_map, norm_type in NORM_TYPE_MAP:
-        if check == norm_map:
-            return norm_type
+#     for norm_map, norm_type in NORM_TYPE_MAP:
+#         if check == norm_map:
+#             return norm_type
 
-    name = field["name"]
-    check = dict(zip(("type", "format", "items.type", "items.format"), check))
-    raise ApiError(f"Unmapped normalized type: {name}: {check}")
+#     name = field["name"]
+#     check = dict(zip(("type", "format", "items.type", "items.format"), check))
+#     raise ApiError(f"Unmapped normalized type: {name}: {check}")
