@@ -3,9 +3,16 @@
 import click
 
 from ...context import AliasedGroup
-from . import (cmd_add, cmd_add_from_json, cmd_delete_by_name,
-               cmd_delete_by_tags, cmd_get, cmd_get_by_name, cmd_get_by_tags,
-               cmd_get_tags)
+from . import (
+    cmd_add,
+    cmd_add_from_json,
+    cmd_delete_by_name,
+    cmd_delete_by_tags,
+    cmd_get,
+    cmd_get_by_name,
+    cmd_get_by_tags,
+    cmd_get_tags,
+)
 
 
 @click.group(cls=AliasedGroup)
