@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 """Test suite for assets."""
 import pytest
+
 from axonius_api_client.constants import AGG_ADAPTER_ALTS, AGG_ADAPTER_NAME
 from axonius_api_client.exceptions import ApiError, NotFoundError
 
-from ...meta import (FIELD_FORMATS, NORM_TYPES, SCHEMA_FIELD_FORMATS,
-                     SCHEMA_TYPES)
+from ...meta import FIELD_FORMATS, SCHEMA_FIELD_FORMATS, SCHEMA_TYPES
 
 
 def load_test_data(apiobj):
@@ -256,7 +256,6 @@ class FieldsPublic:
 
         type_norm = schema.pop("type_norm")
         assert isinstance(type_norm, str) and type_norm
-        assert type_norm in NORM_TYPES
 
         parent = schema.pop("parent")
         assert isinstance(parent, str) and parent
@@ -291,12 +290,21 @@ class FieldsPublic:
         enums = schema.pop("enum", [])
         assert isinstance(enums, list)
 
+        is_agg = schema.pop("is_agg")
+        assert isinstance(is_agg, bool)
+
+        expr_field_type = schema.pop("expr_field_type")
+        assert isinstance(expr_field_type, str)
+
         for enum in enums:
             assert isinstance(enum, str) or isinstance(enum, int)
 
         sub_fields = schema.pop("sub_fields", [])
         assert isinstance(sub_fields, list)
 
+        items = schema.pop("items", {})
+        assert isinstance(items, dict)
+
         if is_complex:
             if name != "all":
                 assert sub_fields
@@ -304,8 +312,6 @@ class FieldsPublic:
             for sub_field in sub_fields:
                 self.val_parsed_schema(adapter=f"{adapter}:{name}", schema=sub_field)
         else:
-            items = schema.pop("items", {})
-
             dynamic = items.pop("dynamic", False)
             assert isinstance(dynamic, bool)
 
